# JSON Utils Package

This is a python package having multiple utilities. 
[Github-flavored Markdown](https://github.com/deepstartup/jsonutils/)
DDLj:Convert the JSON schema file into physical DDL file in .sql format.
Below are the input parameter for the package (1.JSON Schema Path,2.JSON Output Path,3.Glossary File)